@@ -428,6 +428,7 @@ empathy_account_chooser_set_account (EmpathyAccountChooser *chooser,
 
 	data.chooser = chooser;
 	data.account = account;
+	data.set = FALSE;
 
 	gtk_tree_model_foreach (model,
 				(GtkTreeModelForeachFunc) account_chooser_set_account_foreach,
@@ -569,7 +570,7 @@ account_manager_prepared_cb (GObject *source_object,
 	EmpathyAccountChooserPriv *priv = GET_PRIV (chooser);
 	GError *error = NULL;
 
-	if (!tp_account_manager_prepare_finish (manager, result, &error)) {
+	if (!tp_proxy_prepare_finish (manager, result, &error)) {
 		DEBUG ("Failed to prepare account manager: %s", error->message);
 		g_error_free (error);
 		return;
@@ -685,7 +686,7 @@ account_chooser_setup (EmpathyAccountChooser *chooser)
 					NULL);
 
 	/* Populate accounts */
-	tp_account_manager_prepare_async (priv->manager, NULL,
+	tp_proxy_prepare_async (priv->manager, NULL,
 					  account_manager_prepared_cb, chooser);
 
 	g_object_unref (store);
@@ -1016,33 +1017,6 @@ empathy_account_chooser_filter_is_connected (
 	callback (is_connected, callback_data);
 }
 
-typedef struct {
-	EmpathyAccountChooserFilterResultCallback callback;
-	gpointer                                  user_data;
-} FilterCallbackData;
-
-static void
-conn_prepared_cb (GObject *conn,
-		GAsyncResult *result,
-		gpointer user_data)
-{
-	FilterCallbackData *data = user_data;
-	GError             *myerr = NULL;
-	TpCapabilities     *caps;
-
-	if (!tp_proxy_prepare_finish (conn, result, &myerr)) {
-		data->callback (FALSE, data->user_data);
-		g_slice_free (FilterCallbackData, data);
-		return;
-	}
-
-	caps = tp_connection_get_capabilities (TP_CONNECTION (conn));
-	data->callback (tp_capabilities_supports_text_chatrooms (caps),
-			data->user_data);
-
-	g_slice_free (FilterCallbackData, data);
-}
-
 /**
  * empathy_account_chooser_filter_supports_multichat:
  * @account: a #TpAccount
@@ -1063,28 +1037,22 @@ empathy_account_chooser_filter_supports_chatrooms (
 	gpointer                                   user_data)
 {
 	TpConnection       *connection;
-	FilterCallbackData *cb_data;
-	GQuark              features[] = { TP_CONNECTION_FEATURE_CAPABILITIES, 0 };
-
-	if (tp_account_get_connection_status (account, NULL) !=
-		TP_CONNECTION_STATUS_CONNECTED) {
-		callback (FALSE, callback_data);
-		return;
-	}
+	gboolean           supported = FALSE;
+	TpCapabilities     *caps;
 
 	/* check if CM supports multiuser text chat */
 	connection = tp_account_get_connection (account);
-	if (connection == NULL) {
-		callback (FALSE, callback_data);
-		return;
-	}
+	if (connection == NULL)
+		goto out;
 
-	cb_data = g_slice_new0 (FilterCallbackData);
-	cb_data->callback = callback;
-	cb_data->user_data = callback_data;
+	caps = tp_connection_get_capabilities (connection);
+	if (caps == NULL)
+		goto out;
 
-	tp_proxy_prepare_async (connection, features, conn_prepared_cb,
-		cb_data);
+	supported = tp_capabilities_supports_text_chatrooms (caps);
+
+out:
+	callback (supported, callback_data);
 }
 
 gboolean
