@@ -552,7 +552,7 @@ contact_widget_details_update_edit (EmpathyContactWidget *information)
 
           g_object_set_data ((GObject *) w, DATA_FIELD, field);
 
-          g_signal_connect (w, "day-selected-double-click",
+          g_signal_connect (w, "day-selected",
             G_CALLBACK (contact_widget_bday_changed_cb), information);
           g_signal_connect (w, "month-changed",
             G_CALLBACK (contact_widget_bday_changed_cb), information);
@@ -1750,6 +1750,7 @@ contact_widget_contact_setup (EmpathyContactWidget *information)
                                 PANGO_WRAP_WORD_CHAR);
   gtk_label_set_line_wrap (GTK_LABEL (information->label_status),
                            TRUE);
+  gtk_misc_set_alignment (GTK_MISC (information->label_status), 0, 0.5);
 
   if (!(information->flags & EMPATHY_CONTACT_WIDGET_FOR_TOOLTIP))
     gtk_label_set_selectable (GTK_LABEL (information->label_status), TRUE);
