@@ -206,7 +206,8 @@ empathy_irc_network_class_init (EmpathyIrcNetworkClass *klass)
    * EmpathyIrcNetwork::modified:
    * @network: the object that received the signal
    *
-   * Emitted when either a property or a server of the network is modified.
+   * Emitted when either a property or a server of the network is modified or
+   * when a network is activated.
    *
    */
   signals[MODIFIED] = g_signal_new (
@@ -219,6 +220,24 @@ empathy_irc_network_class_init (EmpathyIrcNetworkClass *klass)
       G_TYPE_NONE, 0);
 }
 
+/**
+ * empathy_irc_network_activate:
+ * @self: the name of the network
+ *
+ * Activates a #EmpathyIrcNetwork.
+ *
+ */
+void
+empathy_irc_network_activate (EmpathyIrcNetwork *self)
+{
+  g_return_if_fail (EMPATHY_IS_IRC_NETWORK (self));
+  g_return_if_fail (self->dropped);
+
+  self->dropped = FALSE;
+
+  g_signal_emit (self, signals[MODIFIED], 0);
+}
+
 /**
  * empathy_irc_network_new:
  * @name: the name of the network
