@@ -33,10 +33,6 @@
 
 #define WEB_SITE "http://live.gnome.org/Empathy"
 
-static void about_dialog_activate_link_cb (GtkAboutDialog  *about,
-					   const gchar     *link,
-					   gpointer         data);
-
 static const char *authors[] = {
 	"Alban Crequy",
 	"Andreas Lööw",
@@ -49,7 +45,7 @@ static const char *authors[] = {
 	"Frederic Crozat",
 	"Frederic Peters",
 	"Geert-Jan Van den Bogaerde",
-	"Guillaume Desmottes",
+	"Guillaume Desmottes <guillaume.desmottes@collabora.co.uk>",
 	"Johan Hammar",
 	"Jonatan Magnusson",
 	"Jonny Lamb",
@@ -95,21 +91,11 @@ static const char *license[] = {
 	   "51 Franklin Street, Fifth Floor, Boston, MA 02110-130159 USA")
 };
 
-static void
-about_dialog_activate_link_cb (GtkAboutDialog *about,
-			       const gchar    *link_,
-			       gpointer        data)
-{
-	empathy_url_show (GTK_WIDGET (about), link_);
-}
-
 void
 empathy_about_dialog_new (GtkWindow *parent)
 {
 	gchar *license_trans;
 
-	gtk_about_dialog_set_url_hook (about_dialog_activate_link_cb, NULL, NULL);
-
 	license_trans = g_strconcat (_(license[0]), "\n\n",
 				     _(license[1]), "\n\n",
 				     _(license[2]), "\n\n",
@@ -121,7 +107,7 @@ empathy_about_dialog_new (GtkWindow *parent)
 			       "comments", _("An Instant Messaging client for GNOME"),
 			       "license", license_trans,
 			       "wrap-license", TRUE,
-			       "copyright", "Imendio AB 2002-2007\nCollabora Ltd 2007-2010",
+			       "copyright", "Imendio AB 2002-2007\nCollabora Ltd 2007-2011",
 			       "documenters", documenters,
 			       "logo-icon-name", "empathy",
 			       "translator-credits", _("translator-credits"),
