@@ -1887,7 +1887,7 @@ account_prepare_cb (GObject *source_object,
   TpAccount *account = TP_ACCOUNT (source_object);
   GError *error = NULL;
 
-  if (!tp_account_prepare_finish (account, result, &error))
+  if (!tp_proxy_prepare_finish (account, result, &error))
     {
       DEBUG ("Failed to prepare account: %s", error->message);
       g_error_free (error);
@@ -1903,7 +1903,7 @@ accounts_dialog_account_validity_changed_cb (TpAccountManager *manager,
     gboolean valid,
     EmpathyAccountsDialog *dialog)
 {
-  tp_account_prepare_async (account, NULL, account_prepare_cb, dialog);
+  tp_proxy_prepare_async (account, NULL, account_prepare_cb, dialog);
 }
 
 static void
@@ -2118,7 +2118,7 @@ accounts_dialog_manager_ready_cb (GObject *source_object,
   TpAccountManager *manager = TP_ACCOUNT_MANAGER (source_object);
   GError *error = NULL;
 
-  if (!tp_account_manager_prepare_finish (manager, result, &error))
+  if (!tp_proxy_prepare_finish (manager, result, &error))
     {
       DEBUG ("Failed to prepare account manager: %s", error->message);
       g_error_free (error);
@@ -2177,8 +2177,8 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
   GtkBuilder                   *gui;
   gchar                        *filename;
   EmpathyAccountsDialogPriv    *priv = GET_PRIV (dialog);
-  GtkWidget                    *content_area;
-  GtkWidget *action_area, *vbox, *hbox, *align;
+  GtkWidget *content_area, *action_area;
+  GtkWidget *grid;
   GtkWidget *alig;
   GtkWidget *sw, *toolbar;
   GtkStyleContext *context;
@@ -2264,36 +2264,20 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
       priv->infobar);
   gtk_widget_show (priv->infobar);
 
-  content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (priv->infobar));
+  grid = gtk_grid_new ();
+  gtk_container_add (
+      GTK_CONTAINER (gtk_info_bar_get_content_area (
+          GTK_INFO_BAR (priv->infobar))),
+      grid);
 
   priv->image_type = gtk_image_new_from_stock (GTK_STOCK_CUT,
       GTK_ICON_SIZE_DIALOG);
   gtk_misc_set_alignment (GTK_MISC (priv->image_type), 0.0, 0.5);
-  gtk_box_pack_start (GTK_BOX (content_area), priv->image_type, FALSE, FALSE, 0);
-  gtk_widget_show (priv->image_type);
-
-  vbox = gtk_vbox_new (FALSE, 6);
-  gtk_box_pack_start (GTK_BOX (content_area), vbox, TRUE, TRUE, 0);
-  gtk_widget_show (vbox);
+  gtk_grid_attach (GTK_GRID (grid), priv->image_type, 0, 0, 1, 2);
 
   /* first row */
-  align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-  gtk_widget_show (align);
-
   priv->label_name = gtk_label_new (NULL);
-  gtk_container_add (GTK_CONTAINER (align), priv->label_name);
-  gtk_widget_show (priv->label_name);
-
-  gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
-
-  /* second row */
-  align = gtk_alignment_new (0.5, 0.0, 0.0, 0.0);
-  gtk_widget_show (align);
-  hbox = gtk_hbox_new (FALSE, 6);
-  gtk_widget_show (hbox);
-  gtk_container_add (GTK_CONTAINER (align), hbox);
-
-  gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
+  gtk_grid_attach (GTK_GRID (grid), priv->label_name, 1, 0, 3, 1);
 
   /* set up spinner */
   priv->throbber = gtk_spinner_new ();
@@ -2304,21 +2288,20 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
 
   priv->label_status = gtk_label_new (NULL);
   gtk_label_set_line_wrap (GTK_LABEL (priv->label_status), TRUE);
-  gtk_widget_show (priv->label_status);
+  gtk_widget_set_hexpand (priv->label_status, TRUE);
 
-  gtk_box_pack_start (GTK_BOX (hbox), priv->throbber, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->image_status, FALSE, FALSE, 3);
-  gtk_box_pack_start (GTK_BOX (hbox), priv->label_status, TRUE, TRUE, 0);
+  gtk_grid_attach (GTK_GRID (grid), priv->throbber, 1, 1, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), priv->image_status, 2, 1, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), priv->label_status, 3, 1, 1, 1);
 
   /* enabled switch */
-  align = gtk_alignment_new (0.5, 0.5, 1., 0.);
-  gtk_box_pack_start (GTK_BOX (content_area), align, FALSE, TRUE, 0);
-
   priv->enabled_switch = gtk_switch_new ();
-  gtk_container_add (GTK_CONTAINER (align), priv->enabled_switch);
+  gtk_widget_set_valign (priv->enabled_switch, GTK_ALIGN_CENTER);
   g_signal_connect (priv->enabled_switch, "notify::active",
       G_CALLBACK (accounts_dialog_enable_switch_active_cb), dialog);
-  gtk_widget_show_all (align);
+  gtk_grid_attach (GTK_GRID (grid), priv->enabled_switch, 4, 0, 1, 2);
+
+  gtk_widget_show_all (grid);
 
   /* Tweak the dialog */
   gtk_window_set_title (GTK_WINDOW (dialog), _("Messaging and VoIP Accounts"));
@@ -2444,7 +2427,7 @@ do_constructed (GObject *object)
   /* Set up signalling */
   priv->account_manager = tp_account_manager_dup ();
 
-  tp_account_manager_prepare_async (priv->account_manager, NULL,
+  tp_proxy_prepare_async (priv->account_manager, NULL,
       accounts_dialog_manager_ready_cb, dialog);
 
   priv->connectivity = empathy_connectivity_dup_singleton ();
@@ -2517,68 +2500,30 @@ empathy_accounts_dialog_show_application (GdkScreen *screen,
     gboolean if_needed,
     gboolean hidden)
 {
-  GError *error = NULL;
-  GdkDisplay *display;
-  GString *cmd;
-  gchar *path;
-  GAppInfo *app_info;
-  GdkAppLaunchContext *context = NULL;
+  GString *args;
 
-  g_return_if_fail (GDK_IS_SCREEN (screen));
   g_return_if_fail (!selected_account || TP_IS_ACCOUNT (selected_account));
 
-  /* Try to run from source directory if possible */
-  path = g_build_filename (g_getenv ("EMPATHY_SRCDIR"), "src",
-      "empathy-accounts", NULL);
-
-  if (!g_file_test (path, G_FILE_TEST_EXISTS))
-    {
-      g_free (path);
-      path = g_build_filename (BIN_DIR, "empathy-accounts", NULL);
-    }
-
-  cmd = g_string_new (path);
-  g_free (path);
+  args = g_string_new (NULL);
 
   if (selected_account != NULL)
-    {
-      g_string_append_printf (cmd, " --select-account=%s",
-          tp_account_get_path_suffix (selected_account));
-    }
+    g_string_append_printf (args, " --select-account=%s",
+        tp_account_get_path_suffix (selected_account));
 
   if (if_needed)
-    g_string_append_printf (cmd, " --if-needed");
+    g_string_append_printf (args, " --if-needed");
 
   if (hidden)
-    g_string_append_printf (cmd, " --hidden");
+    g_string_append_printf (args, " --hidden");
 
   DEBUG ("Launching empathy-accounts (if_needed: %d, hidden: %d, account: %s)",
     if_needed, hidden,
     selected_account == NULL ? "<none selected>" :
       tp_proxy_get_object_path (TP_PROXY (selected_account)));
 
-  app_info = g_app_info_create_from_commandline (cmd->str, NULL, 0, &error);
-  if (app_info == NULL)
-    {
-      DEBUG ("Failed to create app info: %s", error->message);
-      g_error_free (error);
-      goto out;
-    }
+  empathy_launch_program (BIN_DIR, "empathy-accounts", args->str);
 
-  display = gdk_screen_get_display (screen);
-  context = gdk_display_get_app_launch_context (display);
-
-  if (!g_app_info_launch (app_info, NULL, (GAppLaunchContext *) context,
-        &error))
-    {
-      g_warning ("Failed to open accounts dialog: %s", error->message);
-      g_error_free (error);
-    }
-
-out:
-  tp_clear_object (&app_info);
-  tp_clear_object (&context);
-  g_string_free (cmd, TRUE);
+  g_string_free (args, TRUE);
 }
 
 gboolean
